pub struct ParsedMsgHdr {
pub id: MsgId,
pub reply_right: Option<AnySendRight>,
pub voucher: Option<SendRight>,
}Expand description
Represents a parsed message header.
Fields
id: MsgIdThe message ID value from the message header.
reply_right: Option<AnySendRight>The reply port right passed with the message if any.
voucher: Option<SendRight>The voucher port right passed with the message if any.